@@ -1,5 +1,7 @@
-# Copyright (C) 2013 Steven Myint
+#!/usr/bin/env python
 
+# Copyright (C) 2013 Steven Myint
+#
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
 # "Software"), to deal in the Software without restriction, including
@@ -25,6 +27,7 @@ from __future__ import print_function
 from __future__ import unicode_literals
 
 import io
+import signal
 import sys
 
 import autoflake
@@ -33,7 +36,7 @@ import docformatter
 import unify
 
 
-__version__ = '0.5'
+__version__ = '0.5.1'
 
 
 try:
@@ -114,7 +117,8 @@ def format_multiple_files(filenames, args, standard_out, standard_error):
 
     """
     filenames = autopep8.find_files(list(filenames),
-                                    args.recursive, args.exclude)
+                                    args.recursive,
+                                    args.exclude_patterns)
     if args.jobs > 1:
         import multiprocessing
         pool = multiprocessing.Pool(args.jobs)
@@ -142,9 +146,11 @@ def parse_args(argv):
                              'match CPU count if value is less than 1')
     parser.add_argument('-v', '--verbose', action='store_true',
                         help='print verbose messages')
-    parser.add_argument('--exclude', metavar='globs',
-                        help='exclude files/directories that match these '
-                             'comma-separated globs')
+    parser.add_argument('--exclude', action='append',
+                        dest='exclude_patterns', default=[], metavar='pattern',
+                        help='exclude files this pattern; '
+                             'specify this multiple times for multiple '
+                             'patterns')
     parser.add_argument('--version', action='version',
                         version='%(prog)s ' + __version__)
     parser.add_argument('files', nargs='+',
@@ -152,11 +158,6 @@ def parse_args(argv):
 
     args = parser.parse_args(argv[1:])
 
-    if args.exclude:
-        args.exclude = args.exclude.split(',')
-    else:
-        args.exclude = []
-
     if args.jobs < 1:
         import multiprocessing
         args.jobs = multiprocessing.cpu_count()
@@ -164,8 +165,8 @@ def parse_args(argv):
     return args
 
 
-def main(argv, standard_out, standard_error):
-    """Main entry point.
+def _main(argv, standard_out, standard_error):
+    """Internal main entry point.
 
     Return exit status. 0 means no error.
 
@@ -178,3 +179,24 @@ def main(argv, standard_out, standard_error):
         return 1
 
     format_multiple_files(set(args.files), args, standard_out, standard_error)
+
+
+def main():
+    """Main entry point."""
+    try:
+        # Exit on broken pipe.
+        signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+    except AttributeError:  # pragma: no cover
+        # SIGPIPE is not available on Windows.
+        pass
+
+    try:
+        return _main(sys.argv,
+                     standard_out=sys.stdout,
+                     standard_error=sys.stderr)
+    except KeyboardInterrupt:  # pragma: no cover
+        return 2  # pragma: no cover
+
+
+if __name__ == '__main__':
+    sys.exit(main())
